@@ -198,7 +198,7 @@ class ResultsGenerator(object):
                     pass
 
         #return (myusers, myfollowers, myfriends)
-        return (myusers)
+        return (myusers,)
 
     def process_data(self, get_html=False, obj=False):
         if not obj:
